@@ -20,12 +20,12 @@ else:
     _pages_menu = components.declare_component("pages-menu", url="http://localhost:5173")
 
 
-def pages_menu(items: List[MenuItem]) -> str:
-    return _pages_menu(items=items)
+def pages_menu(items: List[MenuItem], selected: Optional[str] = None) -> str:
+    return _pages_menu(items=items, selected=selected)
 
 
 if __name__ == "__main__":
-    items: List[MenuItem] = [
+    ITEMS: List[MenuItem] = [
         {
             "key": "Example 1",
             "label": "Example 1",
@@ -43,4 +43,4 @@ if __name__ == "__main__":
             ],
         },
     ]
-    key = pages_menu(items)
+    key = pages_menu(ITEMS)
